#!/bin/sh -e

#Be careful, the directory of the kernel include files used for the TT device should be specified in the CFLAGS
#(like -I/your/TT/kernel/include/dir) otherwise the library is built against the include files of the kernel
#running on the computer, will not compile if option cap_touch_screen enabled

case "$1" in
at4x0a)
	PLATFORM="at4x0a"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm926ej-s"
	;;
""|s3c24xx)
	PLATFORM="s3c24xx"
	CROSS_BUILD="i686-linux"
	CROSS_TARGET="arm-linux"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920"
	;;
s3c64xx)
        PLATFORM="s3c64xx"
        CROSS_BUILD="i686-pc-linux-gnu"
        CROSS_TARGET="arm-none-linux-gnueabi"
        CROSS_OPT="-O2 -mcpu=arm1176jzf-s -mfpu=vfp -mfp=vfp -march=armv6k -mtune=arm1176jzf-s -mfloat-abi=softfp"
        CROSS_CPU="arm1176jzf-s"
        ;;
bcm4760)
        PLATFORM="bcm4760"
        CROSS_BUILD="i686-pc-linux-gnu"
        CROSS_TARGET="arm-none-linux-gnueabi"
        CROSS_OPT="-O2 -mcpu=arm1136jf-s -mfpu=vfp -mfp=vfp -march=armv6j -mtune=arm1136jf-s -mfloat-abi=softfp"
        CROSS_CPU="arm1136jf-s"
        ;;
omap2)
	PLATFORM="omap2"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
titan2)
	PLATFORM="titan2"
	CROSS_BUILD="i686-pc-linux-gnu"
	#CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	# Compile with SiRF arm code sourcery toolchain
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1136jf-s"
	;;
qemu-arm)
	PLATFORM="qemu-arm"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920t"
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	exit 1
	;;
esac

CAP_TOUCH_SCREEN_EXTRA_CPPFLAG=""
CAP_TOUCH_SCREEN_DIR_EXTENSION=""

case "$2" in
cap_touch_screen)
        if [ $PLATFORM = "s3c64xx" ];then
        CAP_TOUCH_SCREEN_EXTRA_CPPFLAG="-DSUPPORT_MULTIFINGERS_GESTURE_DETECTION"
        CAP_TOUCH_SCREEN_DIR_EXTENSION="-cap-touch-screen"
        fi
        ;;
esac

PROGNAME="tslib"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}${CAP_TOUCH_SCREEN_DIR_EXTENSION}"
INSDIR="${PWD}/ins-${PLATFORM}${CAP_TOUCH_SCREEN_DIR_EXTENSION}"

export BUILD_CC="gcc"
export CC="${CROSS_TARGET}-gcc"
export CPPFLAGS="-DUSE_INPUT_API ${CAP_TOUCH_SCREEN_EXTRA_CPPFLAG}"
export CFLAGS="${CROSS_OPT} -mcpu=${CROSS_CPU} -ffunction-sections -fdata-sections"
export CXX="${CROSS_TARGET}-g++"
export CXXFLAGS="${CFLAGS}"
export F77="${CROSS_TARGET}-g77"
export AS="${CROSS_TARGET}-as"
export LD="${CROSS_TARGET}-ld"
export LDFLAGS="-Wl,--gc-sections"
export AR="${CROSS_TARGET}-ar"
export NM="${CROSS_TARGET}-nm"
export RANLIB="${CROSS_TARGET}-ranlib"
export STRIP="${CROSS_TARGET}-strip"
export ac_cv_func_malloc_0_nonnull="yes"

echo "**** Generating configure..."
./autogen.sh

mkdir -p "${OBJDIR}"
cd "${OBJDIR}"

echo "**** Configuring ${PROGNAME} for ${PLATFORM}..."
"${SRCDIR}/configure"		\
  --build="${CROSS_BUILD}"	\
  --host="${CROSS_TARGET}"	\
  --target="${CROSS_TARGET}"	\
  --prefix=""

echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"
ls -l "${INSDIR}/bin"

# EOF
