/*
 *  tslib/src/ts_read.c
 *
 *  Copyright (C) 2001 Russell King.
 *
 * This file is placed under the LGPL.  Please see the file
 * COPYING for more details.
 *
 * $Id: ts_read.c,v 1.4 2004/07/21 19:12:59 dlowder Exp $
 *
 * Read raw pressure, x, y, and timestamp from a touchscreen device.
 */
#include <sys/stat.h>
#include <fcntl.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "config.h"

#include "tslib-private.h"

#ifdef DEBUG
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#endif


struct touchscreen_linear {
	int     p_offset;
        int     p_mult;
        int     p_div;
        int     a[7];
} lin;

int init_linear_filter(void)
{
	struct stat sbuf;
    	int pcal_fd;
    	char pcalbuf[200];
    	int index;
    	char *tokptr;
    	char *calfile=NULL;
    	char *defaultcalfile = (char*)"/etc/pointercal";

	// Use default values that leave ts numbers unchanged after transform
    lin.a[0] = 1;
    lin.a[1] = 0;
    lin.a[2] = 0;
    lin.a[3] = 0;
    lin.a[4] = 1;
    lin.a[5] = 0;
    lin.a[6] = 1;
    lin.p_offset = 0;
    lin.p_mult   = 1;
    lin.p_div    = 1;

    /*
     * Check calibration file
    */
    if( (calfile = getenv("TSLIB_CALIBFILE")) == NULL) calfile = defaultcalfile;
    if(stat(calfile,&sbuf)==0) {
            pcal_fd = open(calfile,O_RDONLY);
            read(pcal_fd,pcalbuf,200);
            lin.a[0] = atoi(strtok(pcalbuf," "));
            index=1;
            while(index<7) {
                    tokptr = strtok(NULL," ");
                    if(*tokptr!='\0') {
                            lin.a[index] = atoi(tokptr);
                            index++;
                    }
            }
            printf("Linear calibration constants: ");
            for(index=0;index<7;index++) printf("%d ",lin.a[index]);
            printf("\n");
            close(pcal_fd);
    }

    return 0;

}

int linear_filter(int inx, int iny, int* outx, int* outy)
{
	*outx 	 =       ( lin.a[2] +
                           lin.a[0]*inx +
                           lin.a[1]*iny ) / lin.a[6];

        *outy    =       ( lin.a[5] +
                           lin.a[3]*inx +
                           lin.a[4]*iny ) / lin.a[6];

	return 0;

}


