/*
 *  tslib/src/ts_print.c
 *
 *  Derived from tslib/src/ts_test.c by Douglas Lowder
 *  Just prints touchscreen events -- does not paint them on framebuffer
 *
 * This file is placed under the GPL.  Please see the file
 * COPYING for more details.
 *
 * Basic test program for touchscreen library.
 */
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <sys/fcntl.h>
#include <sys/ioctl.h>
#include <sys/mman.h>
#include <sys/time.h>

#include "tslib.h"


int main()
{
	struct tsdev *ts;
	char *tsdevice=NULL;

        if( (tsdevice = getenv("TSLIB_TSDEVICE")) != NULL ) {
                ts = ts_open(tsdevice,0);
        } else {
#ifdef USE_INPUT_API
                ts = ts_open("/dev/input/event0", 0);
#else
                ts = ts_open("/dev/touchscreen/ucb1x00", 0);
#endif /* USE_INPUT_API */
        }

	if (!ts) {
		perror("ts_open");
		exit(1);
	}

	if (ts_config(ts)) {
		perror("ts_config");
		exit(1);
	}

#ifdef SUPPORT_MULTIFINGERS_GESTURE_DETECTION
	printf("Support for multi fingers and gesture recognition enabled. Format of the output:\n");
	printf("Sec Time Stamp - USec Time Stamp - X Finger 1 - Y Finger 1 - Pressure Finger 1 - X Finger 2 - Y Finger 2 - # of Fingers - Gesture ID - Misc Info\n");
#endif

	while (1) {
		struct ts_sample samp;
		int ret;

		ret = ts_read(ts, &samp, 1);

		if (ret < 0) {
			perror("ts_read");
			exit(1);
		}

		if (ret != 1)
			continue;

#ifdef SUPPORT_MULTIFINGERS_GESTURE_DETECTION

		printf("%ld.%06ld: %6d %6d %6d %6d %6d %6d %6d %9d\n", samp.tv.tv_sec, samp.tv.tv_usec, samp.x, samp.y, samp.pressure, samp.finger2_x, samp.finger2_y, samp.fingers, samp.gesture, samp.misc );

#else

                printf("%ld.%06ld: %6d %6d %6d\n", samp.tv.tv_sec, samp.tv.tv_usec, samp.x, samp.y, samp.pressure);

#endif

	}
}
